import asyncio
import uvloop


def get_new_uvloop_queue():
    loop = uvloop.new_event_loop()
    return asyncio.Queue(loop=loop)


new_messages = get_new_uvloop_queue()
users_changed = get_new_uvloop_queue()
online = get_new_uvloop_queue()
offline = get_new_uvloop_queue()
check_online = get_new_uvloop_queue()
is_typing = get_new_uvloop_queue()
read_unread = get_new_uvloop_queue()



import asyncio

new_messages = asyncio.Queue()
users_changed = asyncio.Queue()
online = asyncio.Queue()
offline = asyncio.Queue()
check_online = asyncio.Queue()
is_typing = asyncio.Queue()
read_unread = asyncio.Queue()



# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-08-13 18:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_private_chat', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='message',
            name='read',
            field=models.BooleanField(default=False, verbose_name='Read'),
        ),
    ]
